@@ -385,6 +385,9 @@ http_proc(const char *header, char *body, const int hr, const int blen,
 			    http_sig);
 			cgienv[i++] = sys_benv("SERVER_SOFTWARE=%s",
 			    http_fv_srv);
+			if (rh->x_cte)
+				cgienv[i++] = sys_benv("CONTENT_TYPE=%s",
+				    rh->rq_fv_cte);
 			if (rh->x_clt)
 				cgienv[i++] = sys_benv("CONTENT_LENGTH=%s",
 				    rh->rq_fv_clt);
@@ -1295,6 +1298,7 @@ http_header(const char *header_data, const char *force_status,
 	h->x_agt = 0;
 	h->x_con = 0;
 	h->x_cok = 0;
+	h->x_cte = 0;
 	h->x_clt = 0;
 	h->x_hos = 0;
 	h->x_aut = 0;
@@ -1371,6 +1375,12 @@ http_header(const char *header_data, const char *force_status,
 			strcuts(h->rq_fv_cok, line, ' ', '\0',
 			    sizeof(h->rq_fv_cok));
 		}
+		/* Content-Type: */
+		if (!strcasecmp(option, http_fn_cte)) {
+			h->x_cte = 1;
+			strcuts(h->rq_fv_cte, line, ' ', '\0',
+			    sizeof(h->rq_fv_cte));
+		}
 		/* Content-Length: */
 		if (!strcasecmp(option, http_fn_clt)) {
 			h->x_clt = 1;
