@@ -104,7 +104,7 @@ const char *http_fn_auw		= "WWW-Authenticate:";
 const char *http_fn_ran		= "Range:";
 const char *http_fn_rac		= "Content-Range:";
 const char *http_fn_aen		= "Accept-Encoding:";
-const char *http_fv_srv		= "nostromo 1.8.4";
+const char *http_fv_srv		= "nostromo 1.8.5";
 const char *http_fv_pro		= "HTTP/1.1";
 const char *http_fv_cgi		= "CGI/1.1";
 const char *http_fv_teg		= "chunked";
@@ -664,7 +664,7 @@ main(int argc, char *argv[])
 		SSL_library_init();
 
 		/* create SSL context */
-		if ((ssl_ctx = SSL_CTX_new(SSLv2_server_method())) == NULL)
+		if ((ssl_ctx = SSL_CTX_new(SSLv23_server_method())) == NULL)
 			err(1, "SSL_CTX_new");
 
 		/* load certificate and private key and check them */
@@ -1209,7 +1209,7 @@ main(int argc, char *argv[])
 				continue;
 
 			/* we got a full header sequence */
-			strlcpy(in, c[sdnow].rbuf, sizeof(in));
+			memcpy(in, c[sdnow].rbuf, c[sdnow].roff);
 			rt = c[sdnow].roff;
 			c[sdnow].roff = 0;
 
